@@ -4,39 +4,26 @@ use 5.010;
 use strict;
 use warnings;
 
-use base 'Exporter';
+use base 'Csistck::Test';
+use Csistck::Oper;
+use Csistck::Test::Return;
+
 our @EXPORT_OK = qw/noop/;
 
-use Csistck::Oper;
-use Csistck::Test;
+sub noop { Csistck::Test::NOOP->new(@_); };
 
-sub noop {
-    my $args = shift;
-    my $result = undef;
+sub check {
+    my $self = shift;
 
-    # Set result
-    if (ref $args eq "HASH") {
-        if (defined $args->{result}) {
-            $result = $args->{result};
-        }
-    } 
-    else {
-        $result = $args;
-    }
-
-    return Csistck::Test->new(
-        check => sub { noop_check($result); },
-        repair => sub { noop_check($result); },
-        desc => "NOOP test"
+    return Csistck::Test::Return->new(
+        desc => 'NOOP test',
+        msg => ($self->target) ?
+            'Set to pass' :
+            'Set to fail',
+        resp => ($self->target)
     );
 }
 
-sub noop_check {
-    my $result = shift;
-
-    die("Set to failure") unless ($result);
-}
-
 1;
 __END__
 
