@@ -4,49 +4,57 @@ use 5.010;
 use strict;
 use warnings;
 
-use base 'Exporter';
-our @EXPORT_OK = qw/script/;
-
+use base 'Csistck::Test';
 use Csistck::Oper qw/debug/;
 use Csistck::Config qw/option/;
-use Csistck::Test;
+
+our @EXPORT_OK = qw/script/;
 
 use Digest::MD5;
 use File::Basename;
 use FindBin;
 
 use constant MODE_CHECK => 'check';
-use constant MODE_RUN => 'run';
+use constant MODE_REPAIR => 'run';
 
+# Use the convenience function to normalize args
 sub script {
     my $script = shift;
-    my @args = @_;
-
-    return Csistck::Test->new(
-        check => sub { script_run(MODE_CHECK, $script, @args); },
-        repair => sub { script_run(MODE_RUN, $script, @args); },
-        desc => "Executing script $script"
+    my $script_args = shift // [];
+    my %args = (
+        args => (ref $script_args eq 'ARRAY') ?
+            $script_args :
+            [$script_args],
+        @_
     );
+    Csistck::Test::Script->new($script, %args);
 }
 
-sub script_run {
+sub script_name { shift->{target}; }
+sub args { shift->{args}; }
+
+# Wrap common process function
+sub desc { return sprintf("Script test for %s", shift->script_name); }
+sub check { shift->process(MODE_CHECK); }
+sub repair { shift->process(MODE_REPAIR); }
+
+sub process {
+    my $self = shift;
     my $mode = shift;
-    my $script = shift;
-    my @args = @_;
+    my $script = $self->script_name;
+    # Args was passed as arrayref
+    my @args = @{$self->args};
 
     # TODO sanity check on script
 
     # Build command
     my @command = ($script, $mode, @args);
-    
     debug(sprintf("Run command: cmd=<%s>", join(" ", @command)));
-    
-    # my $ret = system("$cmd 1>/dev/null 2>/dev/null");
     chdir($FindBin::Bin);
     my $ret = system(@command);
-
-    die("Command returned $ret")
-      unless($ret == 0);
+    
+    return (($ret == 0) ? $self->pass('Command passed') :
+      $self->fail('Command failed'));
 }
 
 1;
@@ -60,7 +68,7 @@ Csistck::Test::Script - Csistck script check
 
 =head1 METHODS
 
-=head2 script($script, [@args])
+=head2 script($script, \@args, :\&on_repair)
 
 Call script with extra arguments, if supplied. The first argument passed to
 the script is the run mode, C<MODE_CHECK> or C<MODE_RUN>.
@@ -72,6 +80,8 @@ would be:
 
     /path/to/script/apache2/mod-check check rewrite
 
+If a repair operation is run, the on_repair function is called.
+
 =head1 CONSTANTS
 
 =head2 MODE_CHECK
